interface Optional {
    url?: string;
    fileSize?: number;
    testFrequency?: number;
    onProgress?: (progress: number) => void;
}
/** Class representing a speed tester. */
export default class SpeedTester {
    private url?;
    private fileSize?;
    private testFrequency;
    private onProgress?;
    /**
     * Create a tester.
     * @param {object} optional - The tester config.
     * @param optional.url Links to resources such as downloaded images for testing.
     * @param optional.fileSize When CORS requests is blocked, will use the img tag to test, the fileSize is required.
     * @param optional.testFrequency Testing frequency, default 4.
     * @param optional.onProgress The testing progress callback function.
     */
    constructor(optional?: Optional);
    /**
     * Start testing.
     * @return {number} The testing result.
     */
    start(): Promise<number>;
    /**
     * Can i use the connection api.
     * @return {object} The connection api.
     */
    canIUseConnection(): any;
    /**
     * Preflight request.
     * @return {boolean} whether cors is enabled.
     */
    corsEnabled(url: string): boolean;
    /**
     * Use connection api to test speed.
     * @return {number} The testing result.
     */
    withJsApi(): number;
    /**
     * Use img tag to test speed.
     * @param {string} imgUrl - image link for testing.
     * @param {number} fileSize - image size.
     * @param {string} cb - The testing progress callback function.
     * @return {number} The testing result.
     */
    withImgTag(imgUrl: string, fileSize: number, cb: (progress: number) => void): Promise<number>;
    /**
     * Use ajax to test speed.
     * @param {string} url - Links to resources such as downloaded images for testing.
     * @param {string} cb - The testing progress callback function.
     * @return {number} The testing result.
     */
    withAjax(url: string, cb: (progress: number) => void): Promise<number>;
}
export {};
